summaryrefslogtreecommitdiff
path: root/standalone/android/start.c
diff options
context:
space:
mode:
Diffstat (limited to 'standalone/android/start.c')
-rw-r--r--standalone/android/start.c12
1 files changed, 8 insertions, 4 deletions
diff --git a/standalone/android/start.c b/standalone/android/start.c
index d49a086c7..c67c5da0c 100644
--- a/standalone/android/start.c
+++ b/standalone/android/start.c
@@ -47,11 +47,15 @@ main () {
}
}
/* If this is the first run, set up busybox link. */
if (stat("busybox", &st_buf) != 0) {
- if (link("lib/lib.busybox.so", "busybox") != 0) {
- perror("link busybox");
- exit(1);
+ if (symlink("lib/lib.busybox.so", "busybox") != 0) {
+ /* Just in case! */
+ if (link("lib/lib.busybox.so", "busybox") != 0) {
+ perror("link busybox");
+ exit(1);
+ }
}
}
@@ -47,11 +47,15 @@ main () {
}
}
- /* If this is the first run, set up busybox link. */
+ /* If this is the first run, set up busybox symlink,
+ * which allows busybox to run. */
if (stat("busybox", &st_buf) != 0) {